@@ -1,12 +1,17 @@
 #![deny(
     warnings,
     missing_docs,
+    rustdoc::all,
     clippy::pedantic,
     clippy::missing_inline_in_public_items,
     clippy::dbg_macro
 )]
 #![forbid(unsafe_code)]
-#![allow(clippy::non_ascii_literal, clippy::inline_always)]
+#![allow(
+    rustdoc::missing_doc_code_examples,
+    clippy::non_ascii_literal,
+    clippy::inline_always
+)]
 #![deny(clippy::semicolon_if_nothing_returned)]
 #![cfg_attr(nightly, feature(str_internals, unboxed_closures, fn_traits))]
 #![doc(test(attr(deny(warnings), forbid(unsafe_code))))]
@@ -456,8 +461,8 @@ pub trait CommandExt: Sealed {
     fn rustc_like(&mut self) -> &mut Self;
 
     /// Create a new [`Command`] that runs `rustc` with flags provided by [`Self::rustc_like`].
-    #[inline(always)]
     #[must_use]
+    #[inline(always)]
     fn rustc() -> Self
     where
         Self: Sized,
@@ -468,8 +473,8 @@ pub trait CommandExt: Sealed {
     }
 
     /// Create a new [`Command`] that runs `rustdoc` with flags provided by [`Self::rustc_like`].
-    #[inline(always)]
     #[must_use]
+    #[inline(always)]
     fn rustdoc() -> Self
     where
         Self: Sized,
@@ -528,6 +533,7 @@ pub trait CommandExt: Sealed {
 }
 
 impl Sealed for Command {
+    #[inline(always)]
     fn new(program: &str) -> Self {
         Self::new(program)
     }
@@ -546,6 +552,7 @@ fn display_utf8_lossy(s: &[u8]) -> impl Display + '_ {
     String::from_utf8_lossy(s)
 }
 
+#[inline(always)]
 fn bless() -> bool {
     env::var_os("TRYRUN").as_deref() == Some("bless".as_ref())
 }
@@ -735,8 +742,13 @@ pub mod prelude {
 
 #[cfg(test)]
 mod tests {
-    use super::{normalize, CommandExt, Normalizer, OutputStr};
-    use std::{env::consts, path::Path, process::Command, str};
+    use super::{normalize, CommandExt, Normalizer, Output, OutputStr};
+    use std::{
+        env::consts,
+        path::{Path, PathBuf},
+        process::Command,
+        str,
+    };
 
     #[test]
     fn compare() {
@@ -819,7 +831,10 @@ mod tests {
             .rustc_like()
             .arg("--target=")
             .run_fail(
-                OutputStr::stderr_only("tests/ui/target.stderr"),
+                Output {
+                    stdout: None::<PathBuf>,
+                    stderr: Path::new("tests/ui/target.stderr").into(),
+                },
                 trim_final_newline(),
             );
     }
